=head1 NAME

SPVM::Document::Modules - SPVM Core Modules

=head1 DESCRIPTION

List of SPVM Core Modules

=head1 CORE MODULES

=head2 SPVM::ArrayUtil

L<SPVM::ArrayUtil> - Array Utilities

=head2 SPVM::Byte

L<SPVM::Byte> - byte object

=head2 SPVM::ByteList

L<SPVM::ByteList>

=head2 SPVM::Cloner

L<SPVM::Cloner> - a callback type to clone a object

=head2 SPVM::Comparator::Byte

L<SPVM::Comparator::Byte> - a callback type for byte comparation

=head2 SPVM::Comparator::Short

L<SPVM::Comparator::Short> - a callback type for short comparation

=head2 SPVM::Comparator::Int

L<SPVM::Comparator::Int> - a callback type for int comparation

=head2 SPVM::Comparator::Long

L<SPVM::Comparator::Long> - a callback type for long comparation

=head2 SPVM::Comparator::Float

L<SPVM::Comparator::Float> - a callback type for float comparation

=head2 SPVM::Comparator::Double

L<SPVM::Comparator::Double> - a callback type for double comparation

=head2 SPVM::Comparator::String

L<SPVM::Comparator::String> - a callback type for string comparation

=head2 SPVM::Comparator::Object

L<SPVM::Comparator::Object> - a callback type for object comparation

=head2 SPVM::Complex_2d

L<SPVM::Complex_2d> - 

=head2 SPVM::Complex_2f

L<SPVM::Complex_2f> - 

=head2 SPVM::Double

L<SPVM::Double> - double object

=head2 SPVM::DoubleList

L<SPVM::DoubleList> - 

=head2 SPVM::EqualityChecker

L<SPVM::EqualityChecker> - a callback type to check the object equality

=head2 SPVM::EqualityChecker::SameObject

L<SPVM::EqualityChecker::SameObject> - a callback implementation of L<SPVM::EqualityChecker> to check if the memory addresses of the two objects are equal.

=head2 SPVM::Float

L<SPVM::Float> - float object

=head2 SPVM::FloatList

L<SPVM::FloatList> - 

=head2 SPVM::Hash

L<SPVM::Hash> - 

=head2 SPVM::Hash::Entry

L<SPVM::Hash::Entry>

=head2 SPVM::Int - int object

L<SPVM::Int>

=head2 SPVM::IntList

L<SPVM::IntList> - 

=head2 SPVM::IO::Stderr

L<SPVM::IO::Stderr> - 

=head2 SPVM::IO::Stdout

L<SPVM::IO::Stdout> - 

=head2 SPVM::List

L<SPVM::List> - 

=head2 SPVM::Long

L<SPVM::Long> - long object

=head2 SPVM::LongList

L<SPVM::LongList> - 

=head2 SPVM::Math

L<SPVM::Math> - 

=head2 SPVM::NumberUtil

L<SPVM::NumberUtil> - Number Utilities

=head2 SPVM::Regex

L<SPVM::Regex> - 

=head2 SPVM::Regex::Pattern

L<SPVM::Regex::Pattern> - 

=head2 SPVM::Regex::Replacer

L<SPVM::Regex::Replacer> - 

=head2 SPVM::Short

L<SPVM::Short> - short object

=head2 SPVM::ShortList

L<SPVM::ShortList> - 

=head2 SPVM::StringBuffer

L<SPVM::StringBuffer> - 

=head2 SPVM::Stringer

L<SPVM::Stringer> - a callback type to stringify a object

=head2 SPVM::StringList

L<SPVM::StringList> - 

=head2 SPVM::StringUtil

L<SPVM::StringUtil> - 

=head2 SPVM::Time

L<SPVM::Time> - 

=head2 SPVM::Time::Info

L<SPVM::Time::Info> - 

=head2 SPVM::Unicode

L<SPVM::Unicode> - 
